# -*- coding: utf-8 -*-

from __future__ import absolute_import

import branca.colormap as colormap
import branca.element as element

__version__ = '0.2.0'

__all__ = [
    'colormap',
    'element',
    ]



# -*- coding: utf-8 -*-
"""
Branca Notebooks Tests
----------------------

Here we try to execute all notebooks that are in `branca/examples`.
"""

import os
import sys
import branca.utilities

if sys.version_info[:2] == (3, 4):
    import nbconvert

    rootpath = os.path.abspath(os.path.dirname(__file__))

    class NotebookTester(object):
        def __init__(self, filename):
            self.filename = filename

        def __call__(self, exporter=None, filename=None):
            raw_nb = nbconvert.exporters.Exporter().from_filename(self.filename)
            raw_nb[0].metadata.setdefault('kernelspec', {})['name'] = 'python'
            exec_nb = nbconvert.preprocessors.ExecutePreprocessor().preprocess(*raw_nb)

            if exporter is not None:
                out_nb = nbconvert.exporters.MarkdownExporter().from_notebook_node(*exec_nb)
                if filename is None:
                    assert self.filename.endswith('.ipynb')
                    filename = self.filename[:-6] + exporter.file_extension
                open(filename, 'w').write(out_nb[0].encode('utf-8'))

    class TestNotebooks(object):
        _filepath = rootpath.rstrip('/')+'/../examples/'
        _nblist = [x for x in os.listdir(_filepath) if x.endswith('.ipynb')]

    for fn in TestNotebooks._nblist:
                setattr(TestNotebooks,
                        'test_'+branca.utilities._camelify(fn[:-6]),
                        NotebookTester(TestNotebooks._filepath+fn).__call__
                        )



# -*- coding: utf-8 -*-
""""
Folium Colormap Module
----------------------
"""
import branca.colormap as cm


def test_simple_step():
    step = cm.StepColormap(['green', 'yellow', 'red'],
                           vmin=3., vmax=10.,
                           index=[3, 4, 8, 10], caption='step')
    step = cm.StepColormap(['r', 'y', 'g', 'c', 'b', 'm'])
    step._repr_html_()


def test_simple_linear():
    linear = cm.LinearColormap(['green', 'yellow', 'red'], vmin=3., vmax=10.)
    linear = cm.LinearColormap(['red', 'orange', 'yellow', 'green'],
                               index=[0, 0.1, 0.9, 1.])
    linear._repr_html_()


def test_linear_to_step():
    some_list = [30.6, 50, 51, 52, 53, 54, 55, 60, 70, 100]
    lc = cm.linear.YlOrRd
    lc.to_step(n=12)
    lc.to_step(index=[0, 2, 4, 6, 8, 10])
    lc.to_step(data=some_list, n=12)
    lc.to_step(data=some_list, n=12, method='linear')
    lc.to_step(data=some_list, n=12, method='log')
    lc.to_step(data=some_list, n=30, method='quantiles')
    lc.to_step(data=some_list, quantiles=[0, 0.3, 0.7, 1])
    lc.to_step(data=some_list, quantiles=[0, 0.3, 0.7, 1], round_method='int')
    lc.to_step(data=some_list, quantiles=[0, 0.3, 0.7, 1],
               round_method='log10')


def test_step_to_linear():
    step = cm.StepColormap(['green', 'yellow', 'red'],
                           vmin=3., vmax=10.,
                           index=[3, 4, 8, 10], caption='step')
    step.to_linear()


def test_linear_object():
    cm.linear.OrRd._repr_html_()
    cm.linear.PuBu.to_step(12)
    cm.linear.YlGn.scale(3, 12)
    cm.linear._repr_html_()



# -*- coding: utf-8 -*-
""""
Folium Element Module class IFrame
----------------------
"""
import branca.element as elem
from selenium import webdriver


def test_create_empty_iframe():
    iframe = elem.IFrame()
    iframe.render()


def test_create_iframe():
    iframe = elem.IFrame(html="<p>test content<p>", width=60, height=45)
    iframe.render()


def test_rendering_utf8_iframe():
    iframe = elem.IFrame(html=u"<p>Cerrahpaşa Tıp Fakültesi</p>")
    driver = webdriver.PhantomJS()
    driver.get("data:text/html," + iframe.render())
    driver.switch_to.frame(0)
    assert u"Cerrahpaşa Tıp Fakültesi" in driver.page_source
